nut constant

IconData const nut

Represents the nut icon from the Lucide icon set.

nut

Description:

  • The nut icon is a graphical symbol that conveys a specific idea or functionality related to hazelnut, acorn, food, diet.
  • It belongs to the categories: food-beverage

Acknowledgements:

Implementation

static const IconData nut =
    IconData(0xe39b, fontFamily: _fontFamily, fontPackage: _fontPackage);