git_commit_horizontal constant
IconData
const git_commit_horizontal
Represents the git_commit_horizontal icon from the Lucide icon set.
Description:
- The git_commit_horizontal icon is a graphical symbol that conveys a specific idea or functionality related to code, version control, waypoint, stop, station.
- It belongs to the categories: development, navigation
Acknowledgements:
Implementation
static const IconData git_commit_horizontal = IconData(0xe0e3, fontFamily: _fontFamily, fontPackage: _fontPackage);